@@ -79,6 +79,8 @@ class HdDB:
                     .replace({"nan": "", "NaN": "", "None": ""})
                 )
 
+                self.conn.register("df_renamed", df_renamed)
+
                 # Create the table with VARCHAR columns
                 column_definitions = ", ".join(
                     f'"{col}" VARCHAR' for col in df_renamed.columns
@@ -86,7 +88,6 @@ class HdDB:
 
                 create_table_query = f"CREATE TABLE {table_name} ({column_definitions})"
                 self.execute(create_table_query)
-
                 # Insert all data at once using the DataFrame directly
                 self.execute(f"INSERT INTO {table_name} SELECT * FROM df_renamed")
 
@@ -205,11 +206,11 @@ class HdDB:
         try:
             # Fetch data from the specified table
             data_query = f'SELECT * FROM "{org}__{db}"."{tbl}"'
-            data = self.execute(data_query).fetchdf()
+            data = self.execute(data_query).fetch_df()
 
             # Fetch field information
             fields_query = f'SELECT * FROM "{org}__{db}".hd_fields WHERE tbl = ?'
-            fields = self.execute(fields_query, [tbl]).fetchdf()
+            fields = self.execute(fields_query, [tbl]).fetch_df()
 
             # Convert DataFrames to JSON objects
             data_json = json.loads(
@@ -247,7 +248,6 @@ class HdDB:
                 - count: Total number of records
         """
         try:
-
             end_row = params.end_row or 0
             start_row = params.start_row or 0
             page_size = end_row - start_row
@@ -285,18 +285,19 @@ class HdDB:
         :return: Dictionary containing the record data and fields, or null values if no data found
         """
         try:
-            data_query = f'SELECT * FROM "{org}__{db}"."{tbl}" WHERE rcd___id = ?'
-            record = self.execute(data_query, [id]).fetchone()
+            # Obtener el registro como DataFrame
+            result_df = self.execute(
+                f'SELECT * FROM "{org}__{db}"."{tbl}" WHERE rcd___id = ?', [id]
+            ).fetch_df()
 
-            if record:
+            if not result_df.empty:
+                # Convertir la primera fila del DataFrame a un diccionario
+                record_dict = result_df.iloc[0].to_dict()
+                # Obtener los campos
                 fields_query = f'SELECT * FROM "{org}__{db}".hd_fields WHERE tbl = ?'
                 fields = self.execute(fields_query, [tbl]).fetchdf()
                 fields_json = fields.to_dict(orient="records")
 
-                # Convert record tuple to a dictionary with column names as keys
-                column_names = [field["id"] for field in fields_json]
-                record_dict = dict(zip(column_names, record))
-
                 return {"data": record_dict, "fields": fields_json}
             else:
                 return {"data": None, "fields": None}
@@ -343,8 +344,8 @@ class HdDB:
 
         :param org: Organization name
         :param db: Database name
+        :param tbl: Name of the new table
         :param df: Pandas DataFrame containing the data to be added
-        :param table_name: Name of the new table
         :raises ConnectionError: If there's an error adding the table to MotherDuck
         """
         try:
@@ -358,6 +359,9 @@ class HdDB:
                 .replace({"nan": "", "NaN": "", "None": ""})
             )
 
+            # register table for duckdb
+            self.conn.register("df_renamed", df_renamed)
+
             # Begin transaction
             self.execute("BEGIN TRANSACTION;")
 
@@ -706,6 +710,9 @@ class HdDB:
 
             self.execute("BEGIN TRANSACTION;")
 
+            # Register the DataFrame as a table in DuckDB
+            self.conn.register("data_reordered", data_reordered)
+
             # Insert data into the table
             self.execute(
                 f'INSERT INTO "{org}__{db}"."{tbl}" SELECT * FROM data_reordered'
@@ -924,7 +931,7 @@ class HdDB:
             self.execute("ROLLBACK;")
             logger.error(f"Error clearing values in column: {e}")
             raise QueryError(f"Error clearing values in column: {e}")
-    
+
     @attach_motherduck
     def get_tables(self, org: str, db: str):
         try:
